A sample MArrayLM object, generated with limma
Details
This MArrayLM object contains the results of a Differential
Expression Analysis performed on data from the macrophage package, more
precisely contrasting the counts from macrophage associated with different
stimulation conditions, including IFNg treatment, Salmonella infection, and
their combined effects.
The code to create said object can be found in the folder /inst/scripts in
the DeeDeeExperiment package, the file is called generate_data.R.